bro_global_manager library
Classes
- AbsGlobalManager
- This is an abstract class to build the global manager of the application.
Enums
- GlobalManagerStatus
- This is the status of the global manager.
Mixins
- MixinManagerWithLogger
- A mixin that adds a logger to a manager.
Functions
-
appLoggerHelper(
) → LoggerHelper - Get the main logger helper from the global manager.
-
globalGetManager<
Manager extends AbsWithLifeCycle> () → Manager -
Get the manager of type
Managerfrom the global manager.
Exceptions / Errors
- ManagerRegisteringDeadLoopError
- Error thrown when a dead loop is detected while registering managers.